@@ -16,7 +16,6 @@ class PrinterOptions;
 }
 
 class QAbstractButton;
-class QTextCodec;
 
 class PrinterOptions : public PrinterPage
 {
@@ -55,7 +54,7 @@ private:
     QString m_filename;
     ppd_file_t *m_ppd = nullptr;
     int m_changes = 0;
-    QTextCodec *m_codec = nullptr;
+    const char *m_codec = nullptr;
     QHash<QString, QObject *> m_customValues;
     QString m_make, m_makeAndModel;
 };
